# PythonPackageStructure

### General Instruction 
 - Your datasets should be stored in the data folder
 - Your scripts should be stored in the script folder
 - Your notebooks should be stored in the notebook folder
 - Your models should be stored in the model folder
 - Your test files/scripts should be stored in the tests folder
 - All travis yml files should be stored in the root folder
 - Any other files should be placed in the appropriate folder or directory